/* Copyright (c) 2015-present, salesforce.com, inc. All rights reserved
Licensed under BSD 3-Clause - see LICENSE.txt or git.io/sfdc-license */

import SdsSpec from '@salesforce-ux/sds-button/button.spec.md';
import ReadMe from './README.md';

export default {
  title: 'Product Subsystem/Components/Button',
  argTypes: {
    variant: {
      control: {
        type: 'select',
        options: [
          'neutral',
          'brand',
          'brand-outline',
          'inverse',
          'success',
          'destructive',
          'text-destructive',
        ],
      },
      defaultValue: 'neutral',
    },
    size: {
      control: { type: 'select', options: ['default', 'stretch'] },
      defaultValue: 'default',
    },
    disabled: {
      control: {
        type: 'boolean',
      },
      defaultValue: false,
    },
    label: {
      control: {
        type: 'text',
      },
      defaultValue: 'Button',
    },
  },
};

export const GettingStarted = () => `
  <sds-guideline-wrapper>
    ${ReadMe}
  </sds-guideline-wrapper>
`;

export const Spec = () => `
  <sds-guideline-wrapper>
    ${SdsSpec}
  </sds-guideline-wrapper>
`;

const TextTemplate = (args) => `
<div style="padding: 0.5rem; ${
  args.variant === 'inverse' ? 'background: var(--sds-g-color-brand-inverse-2);' : ''
}">
  <slds-button variant=${args.variant} size=${args.size} ${args.disabled ? 'disabled' : ''}>
    ${args.label}
  </slds-button>
</div>
`;
export const Text = TextTemplate.bind({});

const TextAndIconTemplate = (args) => `
<div style="padding: 0.5rem; ${
  args.variant === 'inverse' ? 'background: var(--sds-g-color-brand-inverse-2);' : ''
}">
  <slds-button variant=${args.variant} size=${args.size} ${args.disabled ? 'disabled' : ''}>
    ${args.label}
    <span slot="end">↓</span>
  </slds-button>
</div>
`;
export const TextAndIcon = TextAndIconTemplate.bind({});

const IconTemplate = (args) => `
<div style="padding: 0.5rem; ${
  args.variant === 'inverse' ? 'background: var(--sds-g-color-brand-inverse-2);' : ''
}">
  <slds-button variant=${args.variant} size=${args.size} ${args.disabled ? 'disabled' : ''}>
    <span slot="end">↓</span>
  </slds-button>
</div>
`;
export const Icon = IconTemplate.bind({});
